@@ -7,4 +7,8 @@ class RecaptchaResponseNotFound(Exception):
         super().__init__('Recaptcha response not found.')
         
 class ConnectionError(Exception):
-    pass
\ No newline at end of file
+    pass
+
+class IpBlock(Exception):
+    def __init__(self):
+        super().__init__('Too many tries for solving reCaptchaV2 using speech to text, take a break or change your ip.')
\ No newline at end of file
